======
V1 API
======

.. autotype:: solum.api.controllers.common_types.Link
   :members:

Platform
--------

.. autotype:: solum.api.controllers.v1.root.Platform
   :members:

Plans
-----

.. rest-controller:: solum.api.controllers.v1.plan:PlansController
   :webprefix: /v1/plans

.. rest-controller:: solum.api.controllers.v1.plan:PlanController
   :webprefix: /v1/plans

.. autotype:: solum.api.controllers.v1.datamodel.plan.Plan
   :members:

Pipelines
---------

.. rest-controller:: solum.api.controllers.v1.pipeline:PipelinesController
   :webprefix: /v1/pipelines

.. rest-controller:: solum.api.controllers.v1.pipeline:PipelineController
   :webprefix: /v1/pipelines

.. autotype:: solum.api.controllers.v1.datamodel.pipeline.Pipeline
   :members:

Executions
----------

.. rest-controller:: solum.api.controllers.v1.execution:ExecutionsController
   :webprefix: /v1/pipelines/(pipeline_id)/executions

.. autotype:: solum.api.controllers.v1.datamodel.execution.Execution
   :members:

Assemblies
----------

.. rest-controller:: solum.api.controllers.v1.assembly:AssembliesController
   :webprefix: /v1/assemblies

.. rest-controller:: solum.api.controllers.v1.assembly:AssemblyController
   :webprefix: /v1/assemblies

.. autotype:: solum.api.controllers.v1.datamodel.assembly.Assembly
   :members:

Services
--------

.. rest-controller:: solum.api.controllers.v1.service:ServicesController
   :webprefix: /v1/services

.. rest-controller:: solum.api.controllers.v1.service:ServiceController
   :webprefix: /v1/services

.. autotype:: solum.api.controllers.v1.datamodel.service.Service
   :members:

Operations
----------

.. rest-controller:: solum.api.controllers.v1.operation:OperationsController
   :webprefix: /v1/operations

.. rest-controller:: solum.api.controllers.v1.operation:OperationController
   :webprefix: /v1/operations

.. autotype:: solum.api.controllers.v1.datamodel.operation.Operation
   :members:

Sensors
-------

.. rest-controller:: solum.api.controllers.v1.sensor:SensorsController
   :webprefix: /v1/sensors

.. rest-controller:: solum.api.controllers.v1.sensor:SensorController
   :webprefix: /v1/sensors

.. autotype:: solum.api.controllers.v1.datamodel.sensor.Sensor
   :members:

Components
----------

.. rest-controller:: solum.api.controllers.v1.component:ComponentsController
   :webprefix: /v1/components

.. rest-controller:: solum.api.controllers.v1.component:ComponentController
   :webprefix: /v1/components

.. autotype:: solum.api.controllers.v1.datamodel.component.Component
   :members:


Extensions
----------

.. rest-controller:: solum.api.controllers.v1.extension:ExtensionsController
   :webprefix: /v1/extensions

.. rest-controller:: solum.api.controllers.v1.extension:ExtensionController
   :webprefix: /v1/extensions

.. autotype:: solum.api.controllers.v1.datamodel.extension.Extension
   :members:

LanguagePacks
-------------

.. rest-controller:: solum.api.controllers.v1.language_pack:LanguagePacksController
   :webprefix: /v1/language_packs

.. rest-controller:: solum.api.controllers.v1.language_pack:LanguagePackController
   :webprefix: /v1/language_packs

.. autotype:: solum.api.controllers.v1.datamodel.language_pack.LanguagePack
   :members:

Infrastructure
--------------

.. rest-controller:: solum.api.controllers.v1.infrastructure:InfrastructureController
   :webprefix: /v1/infrastructure

.. autotype:: solum.api.controllers.v1.datamodel.infrastructure.Infrastructure
   :members:

Triggers
--------

.. rest-controller:: solum.api.controllers.v1.trigger:TriggerController
   :webprefix: /v1/triggers
